@@ -1,6 +1,7 @@
 ;;; planner-diary.el --- Diary integration for the Emacs Planner (planner.el)
 
-;; Copyright (C) 2003, 2004 Thomas Gehrlein <Thomas.Gehrlein@t-online.de>
+;; Copyright (C) 2003, 2004 Thomas Gehrlein <Thomas.Gehrlein AT t-online.de>
+;; Parts copyright (C) 2004 Travis B. Hartwell <nafai AT travishartwell.net>
 
 ;; Emacs Lisp Archive Entry
 ;; Filename: planner-diary.el
@@ -515,7 +516,7 @@ from FILE.  DATE is a list (month day year).  NO-OF-DAYS defaults to
                                    (or file
                                        planner-diary-public-file)))
 
-(defsubst planner-diary-get-name ()
+(defun planner-diary-get-name ()
   "Return current filename."
   (file-name-nondirectory (or (buffer-file-name) (buffer-name))))
 
