@@ -10,7 +10,7 @@
 
 ;; Emacs Lisp Archive Entry
 ;; Filename: planner.el
-;; Version: 3.23
+;; Version: 3.27
 ;; Keywords: hypermedia erc chat
 ;; Author: Sacha Chua <sacha@free.net.ph>
 ;; Description: Create tasks and notes based on IRC
@@ -72,7 +72,7 @@ This function can be added to `planner-annotation-functions'."
                   (emacs-wiki-make-link
                    (concat "irc://"
                            erc-announced-server-name "/"
-                           nick ",isnick")
+                           (substring nick 1) ",isnick")
                    (concat "Chat with " nick " on "
                            erc-announced-server-name (erc-default-target))))
               (emacs-wiki-make-link
