@@ -1,11 +1,14 @@
 ;;; planner-gnus.el --- Gnus integration for the Emacs Planner
 
-;; Copyright (C) 2001 John Wiegley
-;; Copyright (C) 2003 Sandra Jean Chua
+;; Copyright (C) 2003, 2004 Sandra Jean Chua (sacha AT free.net.ph)
+;; Copyright (C) 2001 John Wiegley (johnw AT gnu.org)
+;; Parts copyright (C) 2004 Sven Kloppenburg (kloppenburg AT informatik.tu-darmstadt.de)
+;; Parts copyright (C) 2004 Magnus Henoch (mange AT freemail.hu)
+;; Parts copyright (C) 2004 Mario Domgrgen (kanaldrache AT gmx.de)
 
 ;; Author: John Wiegley <johnw@gnu.org>
 ;; Maintainer: Sacha Chua <sacha@free.net.ph>
-;; Version: 3.23
+;; Version: 3.27
 ;; Keywords: planner, gnus
 ;; URL: http://sacha.free.net.ph/notebook/wiki/PlannerMode.php#gnus
 
@@ -106,7 +109,8 @@ Suitable for use in `planner-annotation-functions'."
 			     ""
 			   (concat "from "
 				   (planner-get-name-from-address
-                                    (mail-header-from headers))))
+                                    (mail-header-from headers))
+				   " "))
 			 "on "
 			 gnus-newsgroup-name)
 	       (concat "E-Mail "		   
@@ -145,7 +149,8 @@ Suitable for use in `planner-annotation-functions'."
 			       planner-ignored-from-addresses from))
 			 ""
 		       (concat "from "
-			       (planner-get-name-from-address from)))
+			       (planner-get-name-from-address from)
+			       " "))
 		     "on "
 		     newsgroups)
 	   (concat "E-Mail "
@@ -177,7 +182,11 @@ and `planner-gnus-annotation-from-message'."
     (let ((group (match-string 1 url))
           (articles (match-string 2 url)))
       ;; (gnus-fetch-group group 1) ;; always gives us problems
-      (gnus-fetch-group group)
+      (if (featurep 'gnus-registry)
+          (gnus-fetch-group
+           (or (gnus-registry-fetch-group articles)
+               group))
+        (gnus-fetch-group group))
       (mapcar
        (lambda (article-id)
          (gnus-summary-goto-article article-id nil t))
