@@ -1,7 +1,7 @@
 ;;; planner-id.el --- planner.el extension for global task IDs
 ;;
 ;; Copyright (C) 2003 Sacha Chua <sacha@free.net.ph>
-;; Version: 3.23
+;; Version: 3.27
 ;; URL: http://sacha.free.net.ph/notebook/emacs/dev/planner/
 ;;
 ;;; Commentary:
@@ -26,13 +26,6 @@
 ;; easier to use. Other changes (A/B/C, status) can be applied with
 ;; M-x planner-update-task after you edit the buffer.
 ;;
-;;
-;; TODO:
-;; - Add multiple task ID support
-;;   If we have task IDs, then there's nothing to stop us from making many,
-;;   many copies of tasks.  We have to grep through all the planner files in
-;;   order to update them, though, or keep some sort of index.
-;;
 ;; You can get planner.el from
 ;; http://sacha.free.net.ph/notebook/emacs/dev/planner/
 ;;
@@ -74,42 +67,51 @@
 (defvar planner-id-values nil
   "Alist with (key nextvalue) pairs.")
 
-(defvar planner-id-regexp "{{\\(.*\\):\\([0-9]+\\)}}"
+(defvar planner-id-regexp "{{\\([^:]+\\):\\([0-9]+\\)}}"
   "Regexp matching planner IDs.")
 
-(defsubst planner-id-get-id-from-string (string)
+(defun planner-id-get-id-from-string (string)
   "Return the planner ID in STRING as (identifier number)."
   (when (string-match planner-id-regexp string)
     (cons (match-string-no-properties 1 string)
           (match-string-no-properties 2 string))))
 
-(defsubst planner-id-get-current-id ()
+(defun planner-id-get-current-id ()
   "Return the planner ID on the current line as (identifier number)."
   (planner-id-get-id-from-string (buffer-substring (line-beginning-position)
                                                    (line-end-position))))
 
-(defsubst planner-id-format-as-string (id)
+(defun planner-id-format-as-string (id)
   "Return the planner ID as a string of the form {{identifier:number}}."
   (concat "{{" (car id) ":" (cdr id) "}}"))
 
+(defun planner-id-find-task (task-info &optional point)
+  "Find task described by TASK-INFO. If POINT is non-nil, start from there.
+If task is found, move point to line beginning and return non-nil.
+If task is not found, leave point at POINT or the start of the buffer
+and return nil."
+  (goto-char (or point (point-min)))
+  (let ((task-id (planner-id-get-id-from-string
+                  (planner-task-description task-info))))
+    (when (re-search-forward
+           (concat
+            "#[A-C][0-9]*\\s-+.\\s-+"
+            (if task-id
+                (concat ".*?" (regexp-quote (planner-id-format-as-string task-id)))
+              (regexp-quote (planner-task-description task-info)))) nil t)
+      (goto-char (line-beginning-position)))))
+
 ;;; Redeclaration
 (defun planner-id-jump-to-linked-task (&optional info)
   "Display the linked task page.
 If INFO is specified, follow that task instead."
   (interactive)
   (let* ((task-info (or info (planner-current-task-info)))
-         (task-id (planner-id-get-id-from-string
-                   (planner-task-description task-info)))
          (link (and task-info (planner-task-link task-info))))
     (when (planner-local-page-p link)
       (planner-find-file link)
       (widen)
-      (goto-char (point-min))
-      (when (search-forward (if task-id
-                                (planner-id-format-as-string task-id)
-                              (planner-task-description task-info)) nil t)
-        (beginning-of-line)
-        t))))
+      (planner-id-find-task task-info))))
 
 (defun planner-id-save ()
   "Save `planner-id-values' in `planner-id-tracking-file'."
@@ -155,32 +157,12 @@ Update the linked task page, if any."
   (interactive)
   (save-window-excursion
     (save-excursion
-      (let* ((task-info (planner-current-task-info))
-             new-id
-             (buffer (current-buffer)))
+      (let* ((task-info (planner-current-task-info)))
         (unless (or (not task-info) (planner-id-get-current-id))
-          (setq new-id (planner-id-make-global-id "Tasks"))
-          ;; Update the linked page
-          (when (and (planner-task-link task-info)
-                     (planner-jump-to-linked-task))
-            (setq task-info (planner-current-task-info))
-            (setcar (cdr (cdr (cdr (cdr task-info))))
-                    (concat (planner-task-description task-info) " "
-                            (planner-id-format-as-string new-id)))
-            (delete-region (line-beginning-position)
-                           (min (point-max)
-                                (1+ (line-end-position))))
-            (insert (planner-format-task task-info) "\n"))
-          ;; Update the current page
-          (set-buffer buffer)
-          (setq task-info (planner-current-task-info))
-          (setcar (cdr (cdr (cdr (cdr task-info))))
-                  (concat (planner-task-description task-info) " "
-                          (planner-id-format-as-string new-id)))
-          (delete-region (line-beginning-position)
-                         (min (point-max)
-                              (1+ (line-end-position))))
-          (insert (planner-format-task task-info) "\n"))))))
+          (planner-edit-task-description
+           (concat (planner-task-description task-info) " "
+                   (planner-id-format-as-string
+                    (planner-id-make-global-id "Tasks")))))))))
 
 (defun planner-id-update-tasks-on-page (&optional force)
   "Update all tasks on this page.
@@ -191,10 +173,12 @@ If FORCE is non-nil, completed and cancelled tasks are also updated."
   (save-excursion
     (goto-char (point-min))
     (while (re-search-forward
-            (if force
-                "^#[ABC][0-9]+\\s-+.\\s-+.+?{{[^}:]+:[0-9]+}}"
-              "^#[ABC][0-9]+\\s-+[^CX]\\s-+.+?{{[^}:]+:[0-9]+}}") nil t)
-      (planner-update-task)))
+	    (if force
+		"^#[ABC][0-9]*\\s-+.\\s-+.+?{{Tasks:[0-9]+}}"
+	      "^#[ABC][0-9]*\\s-+[^CX]\\s-+.+?{{Tasks:[0-9]+}}") nil t)
+      (planner-update-task)
+      ;; Force the next line to be considered even if planner-multi-update-task kicked in.
+      (forward-line 1)))
   nil)
 
 (defun planner-id-remove-tasks-on-page ()
@@ -203,7 +187,7 @@ This function does _not_ update tasks on linked pages."
   (save-excursion
     (goto-char (point-min))
     (while (re-search-forward
-            "^#[ABC][0-9]+\\s-+.\\(\\s-+{{[^}:]+:[0-9]+}}\\)" nil t)
+            "^#[ABC][0-9]*\\s-+.\\(\\s-+{{Tasks:[0-9]+}}\\)" nil t)
       (replace-match "" t t nil 1))))
 
 (defun planner-id-add-task-id-to-all ()
@@ -212,7 +196,7 @@ Update the linked page, if any."
   (interactive)
   (save-excursion
     (goto-char (point-min))
-    (while (re-search-forward "^#[ABC][0-9]+\\s-" nil t)
+    (while (re-search-forward "^#[ABC][0-9]*\\s-" nil t)
       (planner-id-add-task-id))
     ;; Force refontification
     (font-lock-fontify-buffer)))
@@ -227,9 +211,9 @@ Update the linked page, if any."
         (save-excursion
           (goto-char here)
           (skip-chars-backward " \t\n")
-          (or (looking-at "{{[^}]+}}")
+          (or (looking-at "{{Tasks:[^}]+}}")
               (and (search-backward "{{" (line-beginning-position) t)
-                   (looking-at "{{[^}]+}}"))
+                   (looking-at "{{Tasks:[^}]+}}"))
               (<= here (match-end 0)))))))
 
 (eval-and-compile
@@ -272,21 +256,21 @@ EVENT is the mouse event."
   (when (planner-id-at-point)
     (planner-id-search-id (match-string 0))))
 
-(defvar planner-id-keymap
-  (let ((map (make-sparse-keymap)))
-    (define-key map [return] 'planner-id-follow-id-at-point)
-    (define-key map [(control ?m)] 'planner-id-follow-id-at-point)
-    (define-key map [(shift return)] 'planner-id-follow-id-at-point)
-    (if (featurep 'xemacs)
-        (progn
-          (define-key map [(button2)] 'planner-id-follow-id-at-mouse)
-          (define-key map [(shift button2)] 'planner-id-follow-id-at-mouse))
-      (define-key map [(mouse-2)] 'planner-id-follow-id-at-mouse)
-      (define-key map [(shift mouse-2)] 'planner-id-follow-id-at-mouse))
-    (unless (eq emacs-major-version 21)
-      (set-keymap-parent map planner-mode-map))
-    map)
-  "Local keymap used by planner when on an ID.")
+;; (defvar planner-id-keymap
+;;   (let ((map (make-sparse-keymap)))
+;;     (define-key map [return] 'planner-id-follow-id-at-point)
+;;     (define-key map [(control ?m)] 'planner-id-follow-id-at-point)
+;;     (define-key map [(shift return)] 'planner-id-follow-id-at-point)
+;;     (if (featurep 'xemacs)
+;;         (progn
+;;           (define-key map [(button2)] 'planner-id-follow-id-at-mouse)
+;;           (define-key map [(shift button2)] 'planner-id-follow-id-at-mouse))
+;;       (define-key map [(mouse-2)] 'planner-id-follow-id-at-mouse)
+;;       (define-key map [(shift mouse-2)] 'planner-id-follow-id-at-mouse))
+;;     (unless (eq emacs-major-version 21)
+;;       (set-keymap-parent map planner-mode-map))
+;;     map)
+;;   "Local keymap used by planner when on an ID.")
 
 (defun planner-id-markup (beg end &optional verbose)
   "Highlight IDs as unobtrusive, clickable text from BEG to END.
@@ -300,13 +284,8 @@ VERBOSE is ignored."
      (list
       'face 'planner-id-face
       'intangible nil
-      'keymap planner-id-keymap))))
-
-(defadvice planner-jump-to-linked-task (around planner-id activate)
-  "Replace with `planner-id-jump-to-linked-task'."
-  (setq ad-return-value (planner-id-jump-to-linked-task (ad-get-arg 0))))
-
-(add-hook 'planner-create-task-hook 'planner-id-add-task-id-maybe)
+      ;;'keymap planner-id-keymap
+      ))))
 
 (defun planner-id-update-tasks-maybe ()
   "Update tasks depending on the value of `planner-id-update-automatically'."
@@ -325,6 +304,9 @@ VERBOSE is ignored."
    'planner-id-update-tasks-maybe nil t))
 
 (add-hook 'planner-mode-hook 'planner-id-setup)
+(add-hook 'planner-create-task-hook 'planner-id-add-task-id-maybe)
+(setq planner-jump-to-linked-task-function 'planner-id-jump-to-linked-task)
+(setq planner-find-task-function 'planner-id-find-task)
 
 (provide 'planner-id)
 
