@@ -209,14 +209,14 @@ Output must be to the current buffer, and in Turtle syntax.")
 			 (add-to-list
 			  'results
 			  (vector (buffer-name)
-						 (planner-task-category info)
-						 (planner-task-status info)
-						 (planner-task-date info)
-						 (planner-task-plan info)
-						 (planner-task-description info)
-						 (planner-task-priority info)
-						 (planner-rdf-get-taskid (planner-task-description info))
-						 ))))
+                                  (planner-task-priority info)
+                                  (planner-task-status info)
+                                  (planner-task-date info)
+                                  (planner-task-plan info)
+                                  (planner-task-description info)
+                                  (planner-task-number info)
+                                  (planner-rdf-get-taskid (planner-task-description info))
+                                  ))))
 		(forward-line))
 	 results))
 
@@ -445,8 +445,8 @@ of the standard output to provide customised content."
 					 (concat planner-rdf-task-prefix task-unique-id)))
 	 (mapcar 'planner-rdf-print-tag tags)
 	 (insert "<planner:Task rdf:about=\"" planner-rdf-task-prefix task-unique-id "\">\n")
-	 (insert "\t<task-category>" (elt taskvector 1) "</task-category>\n")
-	 (insert "\t<task-priority>" (elt taskvector 6) "</task-priority>\n")
+	 (insert "\t<task-priority>" (elt taskvector 1) "</task-priority>\n")
+	 (insert "\t<task-number>" (elt taskvector 6) "</task-number>\n")
 	 (insert "\t<task-status>" (elt taskvector 2) "</task-status>\n")
 	 (insert "\t<date>" (planner-rdf-replace-sth (elt taskvector 3) "." "-") "</date>\n")
 	 (if (not (null (elt taskvector 4)))
