@@ -4,7 +4,7 @@
 
 ;; Emacs Lisp Archive Entry
 ;; Filename: planner-rss.el
-;; Version: 3.23
+;; Version: 3.27
 ;; Keywords: hypermedia
 ;; Author: Sacha Chua <sacha@free.net.ph>
 ;; Description: Export planner entries as an RSS feed
@@ -134,19 +134,22 @@ Call with the interactive prefix in order to be prompted for FEED."
                 description title pubdate link category)
             ;; Get the title
             (with-temp-buffer
-              (insert (or (elt info 2) ""))
-              (when (elt info 4)
-                (insert " (" (emacs-wiki-wiki-base (elt info 4)) ")"))
+              (insert (planner-format-note info "" nil nil nil ""))
               (goto-char (point-min))
-              (emacs-wiki-change-project planner-project)
+              (let ((emacs-wiki-project planner-project))
+                (emacs-wiki-change-project planner-project))
               (let ((emacs-wiki-publishing-header "")
                     (emacs-wiki-publishing-footer ""))
-                (setq emacs-wiki-publishing-markup
-                      (remove '["\\`\n*" 0 "<p>\n"]
-                              emacs-wiki-publishing-markup))
-                (setq emacs-wiki-publishing-markup
-                      (remove '["\\([^> \t\n]\\)\\s-*\\'" 0 "\\1\n</p>"]
-                              emacs-wiki-publishing-markup))
+                (mapcar
+                 (lambda (item)
+                   (setq emacs-wiki-publishing-markup
+                         (remove item
+                                 emacs-wiki-publishing-markup)))
+                 (list
+                  '["\\`\n*" 0 "<p>\n"]
+                  '["\\([^> \t\n]\\)\\s-*\\'" 0 "\\1\n</p>"]
+                  '["\n\\([[:blank:]]*\n\\)+" 0 "\n\n</p>\n\n<p>\n"]
+                  '["\\([^>[:space:]]\\)\\s-*\\'" 0 "\\1\n</p>"]))
                 (emacs-wiki-replace-markup)
                 (setq title (buffer-substring-no-properties (point-min)
                                                             (point-max)))))
@@ -161,10 +164,11 @@ Call with the interactive prefix in order to be prompted for FEED."
             ;; Figure out the permalink
             (setq link (concat planner-rss-base-url page "#" (elt info 1)))
             ;; Figure out the category
-            (when (elt info 4)
-              (setq category (concat "<category>"
-                                     (emacs-wiki-wiki-base (elt info 4))
-                                     "</category>")))
+            (let ((note-link (planner-note-link info)))
+              (when note-link
+                (setq category (concat "<category>"
+                                       (emacs-wiki-wiki-base note-link)
+                                       "</category>"))))
             ;; Get the description
             (with-temp-buffer
               (insert (or (elt info 5) ""))
