@@ -4,7 +4,7 @@
 
 ;; Author: John Wiegley <johnw@gnu.org>
 ;; Maintainer: Sacha Chua <sacha@free.net.ph>
-;; Version: 3.23
+;; Version: 3.27
 ;; Keywords: planner, timeclock
 ;; URL: http://sacha.free.net.ph/notebook/wiki/PlannerMode.php#timeclock
 
@@ -44,7 +44,7 @@
 (require 'planner)
 (require 'schedule)
 
-(defsubst planner-schedule-task-estimate (info)
+(defun planner-schedule-task-estimate (info)
   "Return a time estimate for task (INFO) completion, in seconds."
   (when (string-match "\\`\\s-*\\([0-9]+[smhdw]\\)"
                       (planner-task-description info))
