@@ -49,11 +49,11 @@
                       (concat (planner-task-plan task-info) ": "
                               (planner-task-description task-info))
                     (planner-task-description task-info))))
-    (setq planner-timeclock-current-task
-          (planner-task-description task-info))
     (if (timeclock-currently-in-p)
         (timeclock-change nil project)
-      (timeclock-in nil project))))
+      (timeclock-in nil project))
+    (setq planner-timeclock-current-task
+          (planner-task-description task-info))))
 
 (defadvice timeclock-out (after planner-timeclock activate)
   "Clear `planner-timeclock-current-task.'"
@@ -67,6 +67,62 @@
              (timeclock-currently-in-p))
     (timeclock-out 1)))
 
+(defadvice planner-task-pending (after planner-timeclock activate)
+  "Clock out."
+  (when (and planner-timeclock-current-task
+             (string= (planner-task-description (planner-current-task-info))
+                      planner-timeclock-current-task)
+             (timeclock-currently-in-p))
+    (timeclock-out 1)))
+
+(defadvice planner-replan-task (around planner-timeclock activate)
+  "Edit the clocked in task as well."
+  (let ((info (planner-current-task-info)))
+    ad-do-it
+    (with-current-buffer (find-file-noselect timeclock-file)
+      (goto-char (point-min))
+      (while (re-search-forward
+              (concat
+               "^. [^ ]+ [^ ]+ "
+               "\\("
+               (if (planner-task-plan info)
+                   (regexp-quote (planner-task-plan info))
+                 "")
+               "\\)"
+               ": "
+               (regexp-quote (planner-task-description info))
+               "$")
+              nil t)
+        (replace-match (concat " " (ad-get-arg 0)) t t nil 1))
+      (save-buffer)
+      (kill-buffer (current-buffer)))))
+
+(defadvice planner-edit-task-description (around planner-timeclock activate)
+  "Update the timelog as well. Warning! Do not have duplicate tasks!"
+  (let ((info (planner-current-task-info)))
+    (when (string= (planner-task-description info) planner-timeclock-current-task)
+      (setq planner-timeclock-current-task (ad-get-arg 0)))
+    ad-do-it
+    (with-current-buffer (find-file-noselect timeclock-file)
+      (goto-char (point-min))
+      (while (re-search-forward
+              (concat
+               "^. [^ ]+ [^ ]+ "
+               (if (planner-task-plan info)
+                 (concat 
+                  (regexp-quote (planner-task-plan info))
+                  ": ")
+                 "")
+               "\\("
+               (regexp-quote (planner-task-description info))
+               "\\)"
+               "$")
+              nil t)
+        (replace-match (ad-get-arg 0) t t nil 1))
+
+      (save-buffer)
+      (kill-buffer (current-buffer)))))
+
 (defun planner-timeclock-report-tag (beg end highlight-p)
   "Replace the region BEG to END with a timeclock report.
 If HIGHLIGHT-P is non-nil, the output is also displayed."
