@@ -4,7 +4,7 @@
 ;; Parts copyright (C) 2004 Angus Lees (gus AT inodes DOT org)
 
 ;; Author: Yvonne Thomson (yvonne AT thewatch DOT net)
-;; Version: 3.23
+;; Version: 3.27
 ;; Keywords: planner, wanderlust, wl
 ;; URL: http://sacha.free.net.ph/notebook/wiki/PlannerMode.php
 
@@ -48,6 +48,8 @@
 ;;;_ + Contributors
 
 ;; Angus Lees (gus AT inodes DOT org) remade quite a bit of this file.
+;; Jeremy Cowgar (jeremy AT cowgar DOT com)
+;;   Updated to work with Wanderlust 2.12.0
 
 ;;; Code:
 
@@ -73,8 +75,12 @@ Suitable for use in `planner-annotation-functions'."
     (let* ((msgnum (wl-summary-message-number))
            (msg-id (elmo-message-field wl-summary-buffer-elmo-folder
                                        msgnum 'message-id))
-           (wl-message-entity (elmo-msgdb-overview-get-entity
-                               msgnum (wl-summary-buffer-msgdb))))
+           (wl-message-entity
+            (if (fboundp 'elmo-message-entity)
+                (elmo-message-entity
+                 wl-summary-buffer-elmo-folder msgnum)
+              (elmo-msgdb-overview-get-entity
+               msgnum (wl-summary-buffer-msgdb)))))
       (planner-make-link
        (concat "wl://" wl-summary-buffer-folder-name "/" msg-id)
        (concat "E-Mail " (wl-summary-line-from))))))
